@@ -1,11 +1,11 @@
 import os
 import unittest
 
-from tests import get_tests_input_path, get_tests_output_path
+from tests import get_tests_output_path
+from TTS.config import load_config
 from TTS.tts.utils.generic_utils import setup_model
 from TTS.tts.utils.io import save_checkpoint
 from TTS.tts.utils.text.symbols import make_symbols, phonemes, symbols
-from TTS.utils.io import load_config
 from TTS.utils.synthesizer import Synthesizer
 
 
@@ -15,8 +15,8 @@ class SynthesizerTest(unittest.TestCase):
         # pylint: disable=global-statement
         global symbols, phonemes
         config = load_config(os.path.join(get_tests_output_path(), "dummy_model_config.json"))
-        if "characters" in config.keys():
-            symbols, phonemes = make_symbols(**config.characters)
+        if config.has("characters") and config.characters:
+            symbols, phonemes = make_symbols(**config.characters.to_dict())
 
         num_chars = len(phonemes) if config.use_phonemes else len(symbols)
         model = setup_model(num_chars, 0, config)
@@ -25,11 +25,10 @@ class SynthesizerTest(unittest.TestCase):
 
     def test_in_out(self):
         self._create_random_model()
-        config = load_config(os.path.join(get_tests_input_path(), "server_config.json"))
         tts_root_path = get_tests_output_path()
-        config["tts_checkpoint"] = os.path.join(tts_root_path, config["tts_checkpoint"])
-        config["tts_config"] = os.path.join(tts_root_path, config["tts_config"])
-        synthesizer = Synthesizer(config["tts_checkpoint"], config["tts_config"], None, None)
+        tts_checkpoint = os.path.join(tts_root_path, "checkpoint_10.pth.tar")
+        tts_config = os.path.join(tts_root_path, "dummy_model_config.json")
+        synthesizer = Synthesizer(tts_checkpoint, tts_config, None, None)
         synthesizer.tts("Better this test works!!")
 
     def test_split_into_sentences(self):
