@@ -5,10 +5,9 @@ import numpy as np
 import tensorflow as tf
 import torch
 
-from tests import get_tests_input_path
+from TTS.tts.configs import Tacotron2Config
 from TTS.tts.tf.models.tacotron2 import Tacotron2
 from TTS.tts.tf.utils.tflite import convert_tacotron2_to_tflite, load_tflite_model
-from TTS.utils.io import load_config
 
 tf.get_logger().setLevel("INFO")
 
@@ -19,7 +18,7 @@ torch.manual_seed(1)
 use_cuda = torch.cuda.is_available()
 device = torch.device("cuda:0" if torch.cuda.is_available() else "cpu")
 
-c = load_config(os.path.join(get_tests_input_path(), "test_config.json"))
+c = Tacotron2Config()
 
 
 class TacotronTFTrainTest(unittest.TestCase):
